/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail.nodediscovery;

import com.topcoder.web.ui.tag.breadcrumbtrail.AbstractNodeDiscovery;
import com.topcoder.web.ui.tag.breadcrumbtrail.BreadCrumbNode;
import com.topcoder.web.ui.tag.breadcrumbtrail.Helper;

import java.net.URLDecoder;

import javax.servlet.ServletRequest;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.jsp.PageContext;


/**
 * <p>
 * This tag and implementation of the <code>NodeDiscovery</code> will discover the current node from the
 * <code>HttpServletRequest</code>.
 * </p>
 *
 * <p>
 * <strong>Thread Safety:</strong> This class is thread safe in the context of the JSP rendering process
 * </p>
 *
 * @author Pops, TCSDEVELOPER
 * @version 2.0
 */
public class HttpServletNodeDiscoveryTag extends AbstractNodeDiscovery {
    /**
     * <p>
     * Creates a new instance of <code>HttpServletNodeDiscoveryTag</code> class.
     * </p>
     */
    public HttpServletNodeDiscoveryTag() {
        super();
    }

    /**
     * <p>
     * Retrieves the node which represents the current page from an <code>HttpServletRequest</code>. If none is found
     * or if the servletrequest is not of <code>HttpServletRequest</code> type, a <code>null</code> will be returned.
     * The returned node should include any query strings available.
     * </p>
     *
     * @param pageContext A non-null page context to use.
     *
     * @return A non-null node representing the current url or <code>null</code> if the node couldn't be determined.
     *
     * @throws IllegalArgumentException if the <code>pageContext</code> is <code>null</code>.
     */
    public BreadCrumbNode getCurrentNode(PageContext pageContext) {
        Helper.validateNotNull(pageContext, "pageContext");

        // get the request
        ServletRequest request = pageContext.getRequest();

        if (!(request instanceof HttpServletRequest)) {
            // if the request does not exist or is not type of HttpServletRequest, return null
            return null;
        }

        // decode the uri and queryString
        String url = URLDecoder.decode(((HttpServletRequest) request).getRequestURI()) + "?"
            + URLDecoder.decode(((HttpServletRequest) request).getQueryString());

        return new BreadCrumbNode(url, getTitle());
    }
}
