/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail.pathdiscovery;

import com.topcoder.web.ui.tag.breadcrumbtrail.Helper;


/**
 * <p>
 * This abstract implementation of the <code>NodeMatcher</code> interface provides title and url type services to
 * subclasses. This implementation will provide a title and url holder variable and a getter methods.
 * </p>
 *
 * <p>
 * <b>Thread safety: </b> This class is thread safe by being immutable.
 * </p>
 *
 * @author Pops, TCSDEVELOPER
 * @version 2.0
 */
public abstract class AbstractNodeMatcher implements NodeMatcher {
    /**
     * <p>
     * Represents the default title that a node can take if it matches this node matcher. This variable is set by the
     * constructor, is immutable and can never be null nor an empty (trim'd) string.
     * </p>
     */
    private final String title;

    /**
     * <p>
     * Represents the default url that can be used if not contextual information can be used. This variable is set by
     * the constructor, is immutable and can never be null nor an empty (trim'd) string.
     * </p>
     */
    private final String url;

    /**
     * <p>
     * Creates a new instance of <code>AbstractNodeMatcher</code> class with given node url and title.
     * </p>
     *
     * @param title A non-null, non-empty (trim'd) title to use.
     * @param url A non-null, non-empty (trim'd) url to use.
     *
     * @throws IllegalArgumentException if either arg is an empty (trim'd) string
     */
    protected AbstractNodeMatcher(String title, String url) {
        Helper.validateString(title, "title");
        Helper.validateString(url, "url");
        this.title = title;
        this.url = url;
    }

    /**
     * <p>
     * Gets the title of the node.
     * </p>
     *
     * @return A non-null, non-empty (trim'd) string representing the title.
     */
    public String getTitle() {
        return title;
    }

    /**
     * <p>
     * Gets the url of the node.
     * </p>
     *
     * @return A non-null, non-empty (trim'd) string representing the url to us
     */
    public String getUrl() {
        return url;
    }
}
