/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail.pathdiscovery;

import com.topcoder.web.ui.tag.breadcrumbtrail.BreadCrumbNode;

import java.io.Serializable;


/**
 * <p>
 * Defines the contract for a node matcher. Implementations need to provide three functions:
 * </p>
 *
 * <p>
 *
 * <ol>
 * <li>
 * A matching function that will take a node and determine if it matches
 * </li>
 * <li>
 * A default title string used for those nodes that match
 * </li>
 * <li>
 * A default url to use if no contextual information is available
 * </li>
 * </ol>
 *
 * Implementations of this inteface <strong>must</strong> override the equals/hashCode methods because the
 * implementation will be stored in a map (likely a hash map).
 * </p>
 *
 * <p>
 * <strong>Thread Safety:</strong> Implementations of this interface should be thread safe.
 * </p>
 *
 * @author Pops, TCSDEVELOPER
 * @version 2.0
 */
public interface NodeMatcher extends Serializable {
    /**
     * <p>
     * Determines whether the specified node matches this node matcher.
     * </p>
     *
     * @param node A non-null node to test.
     *
     * @return true if the node matches, false otherwise.
     *
     * @throws IllegalArgumentException if the node is null.
     */
    boolean matches(BreadCrumbNode node);

    /**
     * <p>
     * Gets the default title that nodes that match this node matcher can use if their title is not specified.
     * </p>
     *
     * @return A non-null, non-empty (trim'd) string representing the default title.
     */
    String getTitle();

    /**
     * <p>
     * Gets the default url that can be used if contextual node information is not available.
     * </p>
     *
     * @return A non-null, non-empty (trim'd) string representing the url.
     */
    String getUrl();
}
