/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail;

import junit.framework.TestCase;


/**
 * <p>
 * Tests functionality and error cases of <code>BreadCrumbNode</code> class.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 2.0
 */
public class BreadCrumbNodeUnitTest extends TestCase {
    /** Represents the title used to create the <code>BreadCrumbNode</code> instance for testing. */
    private static final String TITLE = "title";

    /** Represents the url used to create the <code>BreadCrumbNode</code> instance for testing. */
    private static final String URL = "url";

    /** Represents the <code>BreadCrumbNode</code> instance used for testing. */
    private BreadCrumbNode node = null;

    /**
     * <p>
     * Sets up the test environment. The test instance is created.
     * </p>
     *
     * @throws Exception any exception to junit.
     */
    protected void setUp() throws Exception {
        node = new BreadCrumbNode(URL, TITLE);
    }

    /**
     * <p>
     * Tests the constructor <code>BreadCrumbNode(String, String)</code> with null url, IllegalArgumentException should
     * be thrown.
     * </p>
     */
    public void testBreadCrumbNode_NullUrl() {
        try {
            new BreadCrumbNode(null, TITLE);
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * <p>
     * Tests the constructor <code>BreadCrumbNode(String, String)</code> with empty url, IllegalArgumentException
     * should be thrown.
     * </p>
     */
    public void testBreadCrumbNode_EmptyUrl() {
        try {
            new BreadCrumbNode(" ", TITLE);
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * <p>
     * Tests the constructor <code>BreadCrumbNode(String, String)</code> with null title, no exception should be
     * thrown.
     * </p>
     */
    public void testBreadCrumbNode_NullTitle() {
        node = new BreadCrumbNode(URL, null);

        assertNotNull("The BreadCrumbNode instance should be created.", node);
        assertEquals("The url should be set properly.", URL,
            UnitTestHelper.getPrivateField(node.getClass(), node, "url"));
        assertEquals("The title should be set properly.", null,
            UnitTestHelper.getPrivateField(node.getClass(), node, "title"));
    }

    /**
     * <p>
     * Tests the constructor <code>BreadCrumbNode(String, String)</code> with empty title, no exception should be
     * thrown.
     * </p>
     */
    public void testBreadCrumbNode_EmptyTitle() {
        node = new BreadCrumbNode(URL, " ");

        assertNotNull("The BreadCrumbNode instance should be created.", node);
        assertEquals("The url should be set properly.", URL,
            UnitTestHelper.getPrivateField(node.getClass(), node, "url"));

        // the title should be set to null
        assertEquals("The title should be set properly.", null,
            UnitTestHelper.getPrivateField(node.getClass(), node, "title"));
    }

    /**
     * <p>
     * Tests the accuracy of constructor: <code>BreadCrumbNode(String, String)</code>.
     * </p>
     */
    public void testBreadCrumbNode_Accuracy() {
        assertNotNull("The BreadCrumbNode instance should be created.", node);
        assertEquals("The url should be set properly.", URL,
            UnitTestHelper.getPrivateField(node.getClass(), node, "url"));
        assertEquals("The title should be set properly.", TITLE,
            UnitTestHelper.getPrivateField(node.getClass(), node, "title"));
    }

    /**
     * <p>
     * Tests the accuracy of method <code>getTitle()</code>.
     * </p>
     */
    public void testGetTitle_Accuracy() {
        assertEquals("The title should be got properly.", TITLE, node.getTitle());
    }

    /**
     * <p>
     * Tests the accuracy of method <code>getUrl()</code>.
     * </p>
     */
    public void testGetUrl_Accuracy() {
        assertEquals("The url should be got properly.", URL, node.getUrl());
    }
}
