/*
 * Copyright (C) 2006 TopCoder Inc., All Rights Reserved.
 */
package com.topcoder.web.ui.tag.breadcrumbtrail.pathdiscovery;

import com.topcoder.web.ui.tag.breadcrumbtrail.UnitTestHelper;

import junit.framework.TestCase;


/**
 * <p>
 * Tests functionality and error cases of <code>AbstractNodeMatcher</code> class.
 * </p>
 *
 * @author TCSDEVELOPER
 * @version 2.0
 */
public class AbstractNodeMatcherUnitTest extends TestCase {
    /** Represents the title used to create the <code>MockAbstractNodeMatcher</code> instance for testing. */
    private static final String TITLE = "title";

    /** Represents the url used to create the <code>MockAbstractNodeMatcher</code> instance for testing. */
    private static final String URL = "url";

    /** Represents the <code>AbstractNodeMatcher</code> instance used for testing. */
    private AbstractNodeMatcher nodeMatcher = null;

    /**
     * <p>
     * Sets up the test environment. The test instance is created.
     * </p>
     *
     * @throws Exception any exception to junit.
     */
    protected void setUp() throws Exception {
        nodeMatcher = new MockAbstractNodeMatcher(TITLE, URL);
    }

    /**
     * <p>
     * Tests the constructor <code>AbstractNodeMatcher(String, String)</code> with null title, IllegalArgumentException
     * should be thrown.
     * </p>
     */
    public void testAbstractNodeMatcher_NullTitle() {
        try {
            new MockAbstractNodeMatcher(null, URL);
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * <p>
     * Tests the constructor <code>AbstractNodeMatcher(String, String)</code> with empty title,
     * IllegalArgumentException should be thrown.
     * </p>
     */
    public void testAbstractNodeMatcher_EmptyTitle() {
        try {
            new MockAbstractNodeMatcher(" ", URL);
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * <p>
     * Tests the constructor <code>AbstractNodeMatcher(String, String)</code> with null url, IllegalArgumentException
     * should be thrown.
     * </p>
     */
    public void testAbstractNodeMatcher_NullUrl() {
        try {
            new MockAbstractNodeMatcher(TITLE, null);
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * <p>
     * Tests the constructor <code>AbstractNodeMatcher(String, String)</code> with empty url, IllegalArgumentException
     * should be thrown.
     * </p>
     */
    public void testAbstractNodeMatcher_EmptyUrl() {
        try {
            new MockAbstractNodeMatcher(TITLE, " ");
            fail("IllegalArgumentException should be thrown");
        } catch (IllegalArgumentException e) {
            // good
        }
    }

    /**
     * <p>
     * Tests the accuracy of constructor: <code>AbstractNodeMatcher(String, String)</code>.
     * </p>
     */
    public void testAbstractNodeMatcher_Accuracy() {
        assertNotNull("The AbstractNodeMatcher instance should be created.", nodeMatcher);
        assertEquals("The url should be set properly.", URL,
            UnitTestHelper.getPrivateField(nodeMatcher.getClass().getSuperclass(), nodeMatcher, "url"));
        assertEquals("The title should be set properly.", TITLE,
            UnitTestHelper.getPrivateField(nodeMatcher.getClass().getSuperclass(), nodeMatcher, "title"));
    }

    /**
     * <p>
     * Tests the accuracy of method <code>getTitle()</code>.
     * </p>
     */
    public void testGetTitle_Accuracy() {
        assertEquals("The title should be got properly.", TITLE, nodeMatcher.getTitle());
    }

    /**
     * <p>
     * Tests the accuracy of method <code>getUrl()</code>.
     * </p>
     */
    public void testGetUrl_Accuracy() {
        assertEquals("The url should be got properly.", URL, nodeMatcher.getUrl());
    }
}
